import QtQuick 2.0
import QtMultimedia 5.0
import Ubuntu.Components 1.1
import QtGraphicalEffects 1.0
import Ubuntu.Components.Popups 1.0
import "Functions.js" as Js

/*!
    \brief MainView with a Label and Button elements.
*/

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "mainView"

    // Note! applicationName needs to match the "name" field of the click manifest
    applicationName: "com.ubuntu.developer.roman2861.fmradio"

    /*
     This property enables the application to change orientation
     when the device is rotated. The default is false.
    */
    //automaticOrientation: true

    // Removes the old toolbar and enables new features of the new header.
    useDeprecatedToolbar: false

    width: units.gu(50)
    height: units.gu(75)

    id: mainview

    Page {
        title: "FM Radio"
        Component.onCompleted: { Js.init(); }
        Rectangle {
            anchors.fill: parent
            z: 100;
            visible: center_actind.running
        }
        Component {
            id: noheadphones
            Dialog {
                id: noheadphonesue
                title: "Please, connect antenna"
                text: "We use headphones as FM antenna. Please, insert headphone now or close app."
                Button {
                    text: "Close app"
                    onClicked: Qt.quit();
                }
            }
        }
        Component {
            id: nohard
            Dialog {
                id: nohardue
                title: "Sorry, no FM support"
                text: "Please, use online radio apps. My app is useless for your device."
                Button {
                    text: "Close app"
                    onClicked: Qt.quit();
                }
            }
        }
        Component {
            id: notav
            Dialog {
                id: notavue
                title: "Oops..."
                text: "Please, close all apps, which can use Audio."
                Button {
                    text: "Close app"
                    onClicked: Qt.quit();
                }
            }
        }
        Radio {
            id: radio
            band: Radio.FM
            onAntennaConnectedChanged: {
                if(antennaConnected==true) {
                    PopupUtils.close(noheadphonesue);
                }
                else {
                    PopupUtils.open(noheadphones);
                }
            }
            onAvailabilityChanged: {
                if(availability===Radio.Available) {
                    PopupUtils.close(notavue);
                }
                else if (availability===Radio.Unavailable) {
                    PopupUtils.open(nohard);
                }
                else {
                    PopupUtils.open(notav);
                }
            }
        }
        ActivityIndicator {
            id: center_actind
            running: true
            anchors.centerIn: parent
        }
        Rectangle {
            width: parent.width
            height: parent.height/2
            color: "transparent"
            Rectangle {
                width: parent.width*0.9
                height: parent.height*0.6
                radius: units.gu(2)
                border.color: "#d5d5d5"
                border.width: units.gu(0.1)
                anchors.centerIn: parent
                color: "#DEECFF"
                Text {
                    anchors.centerIn: parent
                    text: radio.frequency
                    font.pixelSize: units.gu(9)
                    font.bold: true
                    color: UbuntuColors.coolGrey
                }
            }
        }
        Rectangle {
            width: parent.width
            height: parent.height/2
            color: "transparent"
            y: parent.height/2
            Label {
                id: radioName
                text: "RDS - soon"
                fontSize: "x-large"
                anchors.horizontalCenter: parent.horizontalCenter
            }
            Label {
                id: radioSString
                anchors.top: radioName.bottom
                anchors.topMargin: units.gu(2)
                text: ""
                fontSize: "large"
                anchors.horizontalCenter: parent.horizontalCenter
            }
            Button {
                y: units.gu(15)
                onClicked: radio.scanDown();
                anchors.left: parent.left
                anchors.leftMargin: units.gu(5)
                text: "Scan down"
            }
            Button {
                y: units.gu(15)
                onClicked: radio.scanUp();
                anchors.right: parent.right
                anchors.rightMargin: units.gu(5)
                text: "Scan up"
            }
        }
        Rectangle {
            id: signalstrength
            height: units.gu(0.5)
            width: parent.width*radio.signalStrength
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 0
            LinearGradient {
                anchors.fill: parent
                start: Qt.point(0, 0)
                end: Qt.point(mainview.width, 0)
                gradient: Gradient {
                    GradientStop { position: 0.0; color: "red" }
                    GradientStop { position: 0.5; color: "yellow" }
                    GradientStop { position: 1.0; color: "green" }
                }
            }
        }
    }
}

